@@ -299,9 +299,12 @@ def verbnet_matcher(doc):
 	merge_vp(doc)
 	res = []
 	for name, ibeg, iend in verbnet_matcher.matcher(doc):
-		arr = spacy.nlp.vocab[name].text.split(':') 
-		verb_i = ibeg + int(arr[-1]) 
-		res.append( (verb_i, ibeg, iend, arr[0].strip()) ) 
+		try:
+			arr = spacy.nlp.vocab[name].text.split(':') 
+			verb_i = ibeg + int(arr[-1]) 
+			res.append( (verb_i, ibeg, iend, arr[0].strip()) ) 
+		except Exception as e:
+			print ('verbnet ex:', e, name, ibeg, iend)
 	return res 
 
 simple_sent		= lambda doc: len([t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT']) <= 0 
