@@ -33,6 +33,17 @@ def index_doc(did, doc):
 from so import * 
 cursor_sql = lambda query, cursor: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql", json={"query":query, "cursor":cursor}).json() #  move to so/__init__ later
 
+def sqltsv(outfile, query="select dep, gov, lem, pos, count(*) cnt from gzjc where type='tok' group by dep, gov, lem, pos", 
+					rowf = lambda row: "\t".join([str(a) for a in row]) ): # added 2022.7.2
+	cursor=''
+	with open(outfile, 'w') as fw:
+		while True : 
+			res = cursor_sql(query, cursor)  
+			[ fw.write( rowf(row)  + "\n")  for row in res['rows']]
+			cursor = res.get('cursor','') 
+			if not cursor: break
+	print ("finished:", outfile, query, flush=True)
+
 def sqlsi(query): #select lex, count(*)
 	si = Counter()
 	cursor=''
@@ -190,6 +201,10 @@ class ES(object):
 			del doc["_score"]
 			print (json.dumps(doc))  
 
+	def cos_tsv(self, idxname):
+		''' trp(rel, gov, dep, cnt) '''
+		sqltsv(idxname + ".trp", f"select dep, gov, lem, pos, count(*) cnt from {idxname} where type='tok' group by dep, gov, lem, pos")
+
 	def tocos(self, idxname): 
 		''' submit to cos , 2022.6.29 '''
 		dic = {"_sntsum": sntnum(idxname), "_lexsum": lexsum(idxname) }
