@@ -1,14 +1,30 @@
 #from uvirun import * 
 #uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload
-import json,os,uvicorn,time, fastapi,platform,requests,math
+import json,os,uvicorn,time, fastapi,platform,requests,math,re
 import numpy as np
 import pandas as pd
 from collections import Counter,defaultdict
 from fastapi import FastAPI, File, UploadFile,Form, Body
 from fastapi.responses import HTMLResponse
 
-app = globals().get('app', fastapi.FastAPI()) #app=FastAPI(title= "Essay Dsk Data API",description= "data for ***",version= "0.1.0",openapi_url="/fastapi/data_manger.json",docs_url="/fastapi/docs",redoc_url="/fastapi/redoc")
+tags_metadata = [ # https://fastapi.tiangolo.com/tutorial/metadata/
+    {
+        "name": "es",
+        "description": "Elastic search tools",
+    },
+    {
+        "name": "items",
+        "description": "Manage items. So _fancy_ they have their own docs.",
+        "externalDocs": {
+            "description": "Items external docs",
+            "url": "https://fastapi.tiangolo.com/",
+        },
+    },
+]
+
+app = globals().get('app', fastapi.FastAPI(openapi_tags=tags_metadata)) #app=FastAPI(title= "Essay Dsk Data API",description= "data for ***",version= "0.1.0",openapi_url="/fastapi/data_manger.json",docs_url="/fastapi/docs",redoc_url="/fastapi/redoc")
 now	= lambda: time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time()))
+from util import likelihood
 
 @app.get('/')
 def home(): 
